<?php
/*
Plugin Name: Contact Form 7 Map Field
Plugin URI: http://wordpress.org/extend/plugins/contact-form-7-map-field/
Description: This plugin provides a new field to Contact Form 7: a map with a coordinates marker, letting the user mark a location.
Version: 2.1
Author: Ofir Shemesh
Author URI: https://shemesh.wordpress.com/
License: GPLv2 or later
*/

/*  
Copyright (C) 2012 Ofir Shemesh (email: shemeshi at gmail.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/

add_action('plugins_loaded', 'contact_form_7_map_field');
add_action( 'wp_head', 'add_header_content' );

function add_header_content() {
?>
<link id="cf7-map-field-leaflet-css" rel="stylesheet" href="http://cdn.leafletjs.com/leaflet-0.4.4/leaflet.css" />
<!--[if lte IE 8]>
<link id="cf7-map-field-leaflet-ie-css" rel="stylesheet" href="http://cdn.leafletjs.com/leaflet-0.4.4/leaflet.ie.css" />
<![endif]-->
<script id="cf7-map-field-leaflet-js" src="http://cdn.leafletjs.com/leaflet-0.4.4/leaflet.js"></script>
<?php
}

function contact_form_7_map_field() {
	global $pagenow;
	if(function_exists('wpcf7_add_shortcode')) {
		wpcf7_add_shortcode('map', 'wpcf7_map_shorcode_handler', true);
	} else {
		if($pagenow != 'plugins.php') { return; }
		add_action('admin_notices', 'cfhiddenfieldserror');
		wp_enqueue_script('thickbox');
		function cfhiddenfieldserror() {
			$out = '<div class="error" id="messages"><p>';
			if(file_exists(WP_PLUGIN_DIR.'/contact-form-7/wp-contact-form-7.php')) {
				$out .= 'The Contact Form 7 is installed, but <strong>you must activate it</strong> in order for the Contact Form 7 Map Field plugin to work.';
			} else {
				$out .= 'The Contact Form 7 plugin must be installed for the Contact Form 7 Map Field plugin to work. <a href="'.admin_url('plugin-install.php?tab=plugin-information&plugin=contact-form-7&from=plugins&TB_iframe=true&width=600&height=550').'" class="thickbox" title="Contact Form 7">Install Now.</a>';
			}
			$out .= '</p></div>';	
			echo $out;
		}
	}
}

function wpcf7_map_shorcode_handler($tag){
	if ( ! is_array( $tag ) )
		return '';

	$type = $tag['type'];
	$name = $tag['name'];
	$options = (array) $tag['options'];
	$values = (array) $tag['values'];

	if ( empty( $name ) )
		return '';

	$folder = dirname(__FILE__);
	$codeFile = "$folder/map-code-leaflet.html";
	$fh = fopen($codeFile, 'r');
	$theCode = fread($fh, filesize($codeFile));
	fclose($fh);

	$html = '<span class="wpcf7-form-control-wrap ' . $name . '">' . $theCode . '<input id="locationHidden" type="hidden" name="' . $name . '" /></span>';
	return $html;
}


add_action( 'admin_init', 'wpcf7_add_tag_generator_map', 20 );

function wpcf7_add_tag_generator_map() {
	if ( ! function_exists( 'wpcf7_add_tag_generator' ) )
		return;

	wpcf7_add_tag_generator( 'map', __( 'Map', 'wpcf7' ),
		'wpcf7-tg-pane-map', 'wpcf7_tg_pane_map' );
}

function wpcf7_tg_pane_map( &$contact_form ) {
?>
<div id="wpcf7-tg-pane-map" class="hidden">
<form action="">
<table>
<tr><td><?php echo esc_html( __( 'Name', 'wpcf7' ) ); ?><br /><input type="text" name="name" class="tg-name oneline" /></td><td></td></tr>
</table>

<table>
<tr>
<td><code>id</code> (<?php echo esc_html( __( 'optional', 'wpcf7' ) ); ?>)<br />
<input type="text" name="id" class="idvalue oneline option" /></td>

<td><code>class</code> (<?php echo esc_html( __( 'optional', 'wpcf7' ) ); ?>)<br />
<input type="text" name="class" class="classvalue oneline option" /></td>
</tr>

</table>

<div class="tg-tag"><?php echo esc_html( __( "Copy this code and paste it into the form left.", 'wpcf7' ) ); ?><br /><input type="text" name="map" class="tag" readonly="readonly" onfocus="this.select()" /></div>

<div class="tg-mail-tag"><?php echo esc_html( __( "And, put this code into the Mail fields below.", 'wpcf7' ) ); ?><br /><span class="arrow">&#11015;</span>&nbsp;<input type="text" class="mail-tag" readonly="readonly" onfocus="this.select()" /></div>
</form>
</div>
<?php
}

?>